@@ -1,16 +1,16 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: menu.py 1069 2009-03-20 17:23:09Z mac $
+# $Id: menu.py 756 2009-12-28 19:38:47Z icemac $
 
 import zope.viewlet.manager
-import z3c.menu.ready2go
+import icemac.addressbook.browser.menus.interfaces
 import z3c.menu.ready2go.manager
 
 MainMenu = zope.viewlet.manager.ViewletManager(
-    'main', z3c.menu.ready2go.ISiteMenu,
+    'main-menu', icemac.addressbook.browser.menus.interfaces.IMainMenu,
     bases=(z3c.menu.ready2go.manager.MenuManager,))
 
 AddMenu = zope.viewlet.manager.ViewletManager(
-    'add', z3c.menu.ready2go.IAddMenu,
+    'add-menu', icemac.addressbook.browser.menus.interfaces.IAddMenu,
     bases=(z3c.menu.ready2go.manager.MenuManager,))
