@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: table.py 1184 2009-05-12 18:39:39Z mac $
+# $Id: table.py 757 2009-12-29 10:20:46Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import icemac.addressbook.interfaces
@@ -19,12 +19,21 @@ class TitleLinkColumn(z3c.table.column.LinkColumn):
     weight = 2
 
     def getSortKey(self, item):
-        return icemac.addressbook.interfaces.ITitle(item)
+        return icemac.addressbook.interfaces.ITitle(item).lower()
 
     def getLinkContent(self, item):
         return icemac.addressbook.interfaces.ITitle(item)
 
 
+class DeleteLinkColumn(z3c.table.column.LinkColumn):
+    """Column containing the a link to delete the object."""
+
+    header = _(u'')
+    weight = 100
+    linkContent = _(u'Delete')
+    linkName = '@@delete.html'
+
+
 class TruncatedContentColumn(z3c.table.column.GetAttrColumn):
 
     length = 20
@@ -40,9 +49,22 @@ class TruncatedContentColumn(z3c.table.column.GetAttrColumn):
 class Table(z3c.table.table.Table):
     "Table which supports a no-rows-found message."
 
+    startBatchingAt = 1000000
     no_rows_message = u'' # Set at subclass.
 
     def renderTable(self):
         if self.rows:
             return super(Table, self).renderTable()
         return self.no_rows_message
+
+
+class PageletTable(z3c.pagelet.browser.BrowserPagelet, Table):
+    """Render the table in a pagelet which also has a template.
+
+    When no template is required the `Table` class can be used.
+    """
+
+    def __init__(self, *args, **kw):
+        super(PageletTable, self).__init__(*args, **kw)
+        Table.__init__(self, *args, **kw)
+    update = Table.update
