@@ -1,12 +1,15 @@
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: __init__.py 1075 2009-03-21 09:29:00Z mac $
+# $Id: __init__.py 679 2009-11-21 14:33:08Z icemac $
 """Database initialisation and upgrading."""
 
 import zope.app.generations.generations
 
 
+GENERATION = 7
+
+
 manager = zope.app.generations.generations.SchemaManager(
-    minimum_generation=4,
-    generation=4,
+    minimum_generation=GENERATION,
+    generation=GENERATION,
     package_name='icemac.addressbook.generations')
