@@ -1,21 +1,19 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: sources.py 913 2009-01-02 12:47:38Z mac $
+# $Id: sources.py 756 2009-12-28 19:38:47Z icemac $
 
+from icemac.addressbook.i18n import MessageFactory as _
+import icemac.addressbook.export.interfaces
 import stabledict
 import zc.sourcefactory.basic
 import zc.sourcefactory.contextual
 import zope.component
 
-import icemac.addressbook.export.interfaces
-
-from icemac.addressbook.i18n import MessageFactory as _
-
 
 class TitleMappingSource(zc.sourcefactory.basic.BasicSourceFactory):
     "Abstract base class for sources using a mapping between value and title."
-    
+
     _mapping = None # to be set in child class
 
     def getValues(self):
@@ -25,41 +23,26 @@ class TitleMappingSource(zc.sourcefactory.basic.BasicSourceFactory):
         return self._mapping[value]
 
 
-class SexSource(TitleMappingSource):
+class YesNoSource(TitleMappingSource):
     _mapping = stabledict.StableDict(
-        ((u'male', _(u'male')),
-         (u'female', _(u'female'))))
+        ((True, _(u'yes')),
+         (False, _(u'no'))))
+
+yes_no_source = YesNoSource()
 
 
-class SalutationSource(TitleMappingSource):
+class FieldTypeSource(TitleMappingSource):
     _mapping = stabledict.StableDict(
-        ((u'male', _(u'Mr.')), 
-         (u'female', _(u'Ms.'))))
-
-salutation_source = SalutationSource()
-
-
-class PhoneNumberKindSource(TitleMappingSource):
-    _mapping = stabledict.StableDict((
-            (u'cell phone', _(u'cell phone')),
-            (u'private fax', _(u'private fax')),
-            (u'private phone', _(u'private phone')),
-            (u'work fax', _(u'work fax')),
-            (u'work phone', _(u'work phone')),
-            (u'other', _(u'other')),
-            ))
-
-phone_number_kind_source = PhoneNumberKindSource()
-
-
-class WorkPrivateKindSource(TitleMappingSource):
-    _mapping = stabledict.StableDict(
-        ((u'private', _(u'private')),
-         (u'work', _(u'work')),
-         (u'other', _(u'other'))))
-
-
-work_private_kind_source = WorkPrivateKindSource()
+        ((u'Bool', _(u'bool')),
+         (u'Choice', _('choice')),
+         (u'Date', _(u'date')),
+         (u'Datetime', _(u'datetime')),
+         (u'Decimal', _('decimal number')),
+         (u'Int', _(u'integer number')),
+         (u'Text', _(u'text area')),
+         (u'TextLine', _(u'text line')),
+         (u'URI', _(u'URL')),
+         ))
 
 
 class KeywordSource(zc.sourcefactory.basic.BasicSourceFactory):
@@ -88,7 +71,7 @@ class ContextByInterfaceSource(
         for value in context.values():
             if self.interface.providedBy(value):
                 yield value
-    
+
     def getTitle(self, context, value):
         import icemac.addressbook.interfaces # avoid circular import
         return icemac.addressbook.interfaces.ITitle(value)
@@ -101,6 +84,7 @@ class ExporterSource(zc.sourcefactory.basic.BasicSourceFactory):
             icemac.addressbook.export.interfaces.IExporter)
 
     def getTitle(self, value):
-        return u'%s (%s)' % (value.title, value.description)
+        return _(u'${title} (${desc})',
+                 mapping=dict(title=value.title, desc=value.description))
 
 exporter_source = ExporterSource()
